#
# spec file for package tar (Version 1.23)
#
# Copyright (c) 2010 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild


Name:           tar
BuildRequires:  help2man
Url:            http://www.gnu.org/software/tar/
License:        GPLv3+
Group:          System/Base
Provides:       base:/bin/tar
PreReq:         %install_info_prereq
AutoReqProv:    on
Version:        1.23
Release:        2.1
Summary:        GNU implementation of tar ((t)ape (ar)chiver)
Source0:        %name-%version.tar.bz2
#
Patch0:         tar-disable_languages.patch
Patch1:         tar-disable-listed02-test.patch
Patch2:         tar-manpage.patch
Patch3:         tar-wildcards.patch
Patch5:         tar-fortifysourcessigabrt.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Recommends:     xz
Recommends:     tar-lang = %version
%define _bindir  /bin

%if %{undefined lang_package}
%define lang_package(n:) \
%package %{-n:-n %{-n*}-}lang \
Summary: Languages for package %{name} \
Group: System/Localization \
Requires: %{-n:%{-n*}}%{!-n:%{name}} = %{version} \
Provides: %{-n:%{-n*}}%{!-n:%{name}}-lang-all = %{version} \
Supplements: packageand(bundle-lang-other:%{-n:%{-n*}}%{!-n:%{name}}) \
%description %{-n:-n %{-n*}-}lang \
Provides translations to the package %{name}
%endif

%description
This package normally also includes the program "rmt", which provides
remote tape drive control. Since there are compatible versions of 'rmt'
in either the 'star' package or the 'dump' package, we didn't put 'rmt'
into this package. If you are planning to use the remote tape features
provided by tar you have to also install the 'dump' or the 'star'
package.



Authors:
--------
    Melissa O'Neill <oneill@cs.sfu.ca>
    Bruno Haible <haible@clisp.cons.org>
    Dale Worley <worley@ariadne.com>
    David J. MacKenzie <djm@gnu.org>
    Franois Pinard <pinard@iro.umontreal.ca>
    Gerhard Poul <gpoul@gnu.org>
    Jay Fenlason <hack@ai.mit.edu>
    Jeff Dairiki <dairiki@dairiki.org>
    Jim Kingdon <kingdon@ai.mit.edu>
    Joy Kendall <jak@hobbes>
    Machael Stone <mstone@cs.loyola.edu>
    Michael I Bushnell <mib@gnu.org>
    Noah Friedman <friedman@gnu.org>
    Paul Eggert <eggert@twinsun.com>
    Rainer Orth <ro@TechFak.Uni-Bielefeld.DE>
    The King <elvis@gnu.org>
    Tom Tromey <tromey@drip.colorado.edu>


%package backup-scripts
License:        GPLv3+
Summary:        Backup scirpts
Group:          Productivity/Archiving/Backup
Requires:       %{name} = %{version}-%{release}

%description backup-scripts
Shell scripts for system backup/restore

%lang_package
%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch5 -p1

%build
rm -f po/no.* po/ky.*
%if %{?suse_version:%{suse_version}}%{!?suse_version:1110} > 1100
#autoreconf -fi
aclocal -I m4
automake --force --add-missing
%endif
%define my_cflags -W -Wall -Wpointer-arith -Wstrict-prototypes -Wformat-security -Wno-unused-parameter
export CFLAGS="$RPM_OPT_FLAGS %my_cflags"
export RSH="/usr/bin/rsh"
./configure --prefix=%_prefix --bindir=%_bindir --mandir=%_mandir \
	    --infodir=%_infodir --build=%{_target_cpu}-suse-linux \
		--enable-backup-scripts
make %{?_smp_mflags};

if ! test -s doc/tar.1 ; then
    pushd doc
    help2man --name "The GNU version of the tar archiving utility" -p tar ../src/tar > tar.1
    popd
fi

%check
#%ifarch %arm
#make check || true
#%else
#make check
#%endif

%install
make install DESTDIR=$RPM_BUILD_ROOT
install -D -m 644 scripts/backup-specs $RPM_BUILD_ROOT%{_sysconfdir}/backup-specs
rm -r %buildroot/usr/libexec
if ! test -s %{buildroot}%{_mandir}/man1/tar.1 ; then
    mkdir -p %{buildroot}%{_mandir}/man1
    install -m 0644 doc/tar.1 %{buildroot}%{_mandir}/man1/
fi
%find_lang %name

%files lang -f %name.lang

%files backup-scripts
%defattr(-,root, root)
%_sbindir/backup  
%_sbindir/restore  
%config(noreplace) %{_sysconfdir}/backup-specs  

%files
%defattr(-, root, root)
%_bindir/tar
%doc README* ABOUT-NLS AUTHORS COPYING NEWS THANKS ChangeLog TODO
%_infodir/tar.info*.gz
%_mandir/man1/tar.1.gz

%post
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%postun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%clean
rm -rf $RPM_BUILD_ROOT

%changelog
* Mon Jun 28 2010 jengelh@medozas.de
- use %%_smp_mflags
* Fri Mar 12 2010 mseben@novell.com
- updated to version 1.23
  * Improved record size autodetection
  * Use of lseek on seekable archives
  * New command line option --warning
  * New command line option --level
  * Improved behavior if some files were removed during incremental dumps
  * Modification times of PAX extended headers
  * Time references in the --pax-option argument
  * Augmented environment of the --to-command script
  * Fix handling of hard link targets by -c --transform
  * Fix hard links recognition with -c --remove-files
  * Fix restoring files from backup (debian bug #508199)
  * Correctly restore modes and permissions on existing directories
  * The --remove-files option removes files only if they were succesfully stored in the archive
  * Fix storing and listing of the volume labels in POSIX format
  * Improve algorithm for splitting long file names (ustar format)
  * Fix possible memory overflow in the rmt client code (CVE-2010-0624)
- deprecated heap_overflow_in_rtapelib.patch
* Wed Mar  3 2010 mseben@novell.com
- added heap_overflow_in_rtapelib.patch fix possible heap overflow in
  rtapelib.c (bnc#579475)
* Tue Feb  2 2010 mseben@novell.com
- updated to version 1.22
  * Support for xz compression (--xz option)
  * Short option -J is reassigned as a shortcut for --xz
  * The option -I is a shortcut for --use-compress-program
  * The --no-recursive option works with --incremental
- deprecated recognize_xz.patch
- created tar-backup-scripts subpackage (bnc#574688)
* Sun Dec  6 2009 jengelh@medozas.de
- enable parallel building
* Fri Dec  4 2009 meissner@suse.de
- fixed FORTIFY_SOURCE=2 issue with gcc 4.5.
* Sun Aug 30 2009 aj@suse.de
- recommend not require language subpackage
* Tue Mar  3 2009 pth@suse.de
- Recognize .xz as lzma archive.
* Wed Feb 11 2009 coolo@suse.de
- update to version 1.21
  * New short option -J - A shortcut for --lzma.
  * New option --lzop
  * Compressed format recognition
  * Using --exclude-vcs handles also files used internally by
    Bazaar, Mercurial and Darcs.
- split out language subpackage
- recommend xz instead of the old name of lzma
* Wed Nov 19 2008 mkoenig@suse.de
- fix incremental backup with wildcard option [bnc#445411]
* Mon Jun 23 2008 mkoenig@suse.de
- update to version 1.20:
  * new options: --auto-compress, --lzma, --hard-dereference,
  - -checkpoint-action, --(no-)check-device, --transform
  * Add recommends tag for lzma
- removed patches:
  tar-gcc43.patch
  tar-1.19-update_flag.patch
* Fri Mar 28 2008 mkoenig@suse.de
- apply upstream patch to avoid error message when updating
  an archive that does not exist [bnc#347525]
* Wed Nov 14 2007 mkoenig@suse.de
- update to version 1.19
  * New option --exclude-vcs
  * --exclude-tag and --exclude-cache options now work under
    incremental archives
  * Fix handling of renamed files in listed incremental archives
  * Fix --version output
  * Recognition of broken archives
- merged patches:
  tar-1.15.1-CVE-2001-1267.patch
  tar-1.17-paxlib-owl-alloca.patch
* Fri Oct  5 2007 mkoenig@suse.de
- update to version 1.18
  Licensed under the GPLv3
- merged patches:
  tar-1.17-testsuite12.patch
* Mon Oct  1 2007 mkoenig@suse.de
- fix build with gcc-4.3
* Fri Aug 31 2007 mkoenig@suse.de
- fixed another directory traversal vulnerability, CVE-2001-1267,
  CVE-2002-0399, [#29973]
* Mon Aug 20 2007 mkoenig@suse.de
- use correct patch for paxlib stack overflow [#301416]
* Fri Aug 17 2007 lmichnovic@suse.cz
- upstream fix: use of alloca can cause stack overflow
  (paxlib-owl-alloca.patch)
* Thu Jun 21 2007 mkoenig@suse.de
- update to version 1.17:
  * Fix archivation of sparse files in posix mode
  * Fix operation of --verify --listed-incremental
  * Fix --occurence
  * Scope of --transform and --strip-components options
  * End-of-volume script can send the new volume name to tar
- remove patch (fixed upstream)
  tar-1.6.1-futimens.patch
- fix test 12
  tar-1.17-testsuite12.patch
* Tue May 22 2007 mkoenig@suse.de
- fix build
* Tue May 15 2007 coolo@suse.de
- use %%find_lang
* Wed Jan 24 2007 mkoenig@suse.de
- update to version 1.16.1:
  * tar-1.16-CVE-2006-6097.patch merged upstream
  * tar-1.16-xheader_unused.patch merged upstream
  * New option --exclude-tag
  * The --exclude-cache option excludes directories that
    contain the CACHEDIR.TAG file from being archived
  * Race conditions have been fixed that in some cases briefly
    allowed files extracted by 'tar -x --same-owner' to be
    accessed by users that they shouldn't have been.
* Tue Dec  5 2006 mkoenig@suse.de
- update to version 1.16:
  Bugfixes:
  * Avoid running off file descriptors when using multiple -C options.
  * tar --index-file=FILE --file=- sent the archive to FILE, and
    the listing to stderr.
  * Detect attempts to update compressed archives.
  * Allow non-option arguments to be interspersed with options.
  * Previous version created invalid archives when files shrink
    during reading.
  * Compare mode (tar d) hanged when trying to compare file contents.
  * Previous versions in certain cases failed to restore directory
    modification times.
  New features:
  * New option --mtime allows to set modification times
  * New option --transform allows to transform file names before
    storing
  * --strip-components option works when deleting and comparing.
  * New option --show-transformed-names
  * Short option -l is now an alias of --check-links option,
    which complies with UNIX98
  * The --checkpoint option takes an optional argument specifying
    the number of records between the two successive checkpoints.
  * The --totals option can be used with any tar operation
  * Any number of -T (--files-from) options may be used in the
    command line.
  * List files containing null-separated file names are detected
    and processed automatically.
  * New option --no-unquote disables the unquoting of input file
    names.
  * New option --test-label tests the archive volume label.
  * New option --show-stored-names.
  * New option --to-command pipes the contents of archive members
    to the specified command.
  * New option --atime-preserve=system
  * New option --delay-directory-restore
  * New option --restrict prohibits use of some potentially harmful
    tar options.
  * New options --quoting-style and --quote-chars control the way
    tar quotes member names on output.
  * Better support for full-resolution time stamps.
  Incompatible changes:
  * tar no longer uses globbing by default
- remove unused variable [#223847]
- create man page via help2man
- remove support for mangled names, due to security reasons
  CVE-2006-6097 [#223185]
* Mon Jul 24 2006 rguenther@suse.de
- Do not build-depend on rsh, but provide the RSH environment.
* Mon Feb 27 2006 kssingvo@suse.de
- fixed buffer overflow issue CVE-2006-0300 (bugzilla#151516)
- not affected: traversal bug CVE-2005-1918 (bugzilla#145081)
* Sat Feb 18 2006 aj@suse.de
- Fix build.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Sep  1 2005 mmj@suse.de
- Add patch from upstream for fixing sparse files > 4GB [#114540]
* Fri Jun 24 2005 schwab@suse.de
- Fix broken test.
* Fri Apr  8 2005 uli@suse.de
- ignore test suite fails on ARM
* Wed Mar  9 2005 mmj@suse.de
- Make gcc4 happy
* Tue Feb  1 2005 mmj@suse.de
- Disable test that breaks on reiserfs due to that filesystems
  limitations. Tar works fine on reiserfs.
* Tue Dec 21 2004 mmj@suse.de
- Update to 1.15.1 which fixes a bug introduced in 1.15 which caused
  tar to refuse to extract files from standard input.
* Tue Dec 21 2004 mmj@suse.de
- Update to tar-1.15 including:
- Features:
  o Compressed archives are recognised automatically, it is no
    longer necessary to specify -Z, -z, or -j options to read
    them.  Thus, you can now run `tar tf archive.tar.gz'.
  o When restoring incremental dumps, --one-file-system option
    prevents directory hierarchies residing on different devices
    from being purged. With the previous versions of tar it was
    dangerous to create incremental dumps with --one-file-system
    option, since they would recursively remove mount points when
    restoring from the back up. This change fixes the bug.
  o Renamed --strip-path to --strip-components for consistency with
    the GNU convention.
  o Skipping archive members is sped up if the archive media supports
    seeks.
  o Restore script starts restoring only if it is given --all (-a)
    option, or some patterns. This is to prevent accidental restores.
  o `tar --verify' prints a warning if during archive creation some of
    the file names had their prefixes stripped off.
  o New option --exclude-caches instructs tar to exclude cache
    directories automatically on archive creation. Cache directories
    are those containing a standardized tag file, as specified at:
    http://www.brynosaurus.com/cachedir/spec.html
  o New configure option --with-rmt allows to specify full path
    name to the `rmt' utility. This supercedes DEFAULT_RMT_COMMAND
    variable introduced in version 1.14
  o New configure variable DEFAULT_RMT_DIR allows to specify the
    directory where to install `rmt' utility. This is necessary
    since modifying --libexecdir as was suggested for version 1.14
    produced a side effect: it also modified installation prefix
    for backup scripts (if --enable-backup-scripts was given).
- Bugfixes:
  o Fixed flow in recognizing files to be included in incremental dumps.
  o Correctly recognize sparse archive members when used with -T option.
  o GNU multivolume headers cannot store filenames longer than
    100 characters.  Do not allow multivolume archives to begin
    with such filenames.
  o If a member with link count > 2 was stored in the archive twice,
    previous versions of tar were not able to extract it, since they
    were trying to link the file to itself, which always failed and
    lead to removing the already extracted copy. Preserve the first
    extracted copy in such cases.
  o Restore script was passing improper argument to tar --listed
    option (which didn't affect the functionality, but was
    logically incorrect).
  o Fixed verification of created archives.
  o Fixed unquoting of file names containing backslash escapes (previous
    versions failed to recognize \a and \v).
  o When attempting to delete a non-existing member from the
    archive, previous versions of tar used to overwrite last
    archive block with zeroes.
* Mon Aug  9 2004 mmj@suse.de
- Add patch from snwint with long filename fix [#43538]
* Sun May 30 2004 mmj@suse.de
- Update to 1.14 which is the first stable release of tar
  since 1999.
* Thu Apr 15 2004 mmj@suse.de
- Fix detection of remote paths [#38709]. Thanks Jrgen!
* Tue Apr 13 2004 mmj@suse.de
- Update to 1.13.94 including fix for [#16531]
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Fri Jun 20 2003 ro@suse.de
- build with current gettext
* Thu May 15 2003 pthomas@suse.de
- Remove unneeded files from build root.
- Add autoconf tests to properly guard K&R prototypes
- Clean up signed/unsigned compares.
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Fri Feb  7 2003 ro@suse.de
- added install_info macros
* Mon Nov 18 2002 ro@suse.de
- add AM_GNU_GETTEXT_VERSION to configure.ac
* Thu Aug  1 2002 ro@suse.de
- add acinclude.m4 with missing macros
* Tue Jun  4 2002 pthomas@suse.de
- Make tar a package of its own.
- Update to tar-1.13.25.
- Make tar man page a seperate file instead of part of the patch.
- Patch de.po to reflect the addition of the --bunzip2 parameter
- Use AC_LIBOBJ instead of LIBOBJS
* Wed May 22 2002 olh@suse.de
- allow build as user, use buildroot
* Fri Feb  8 2002 werner@suse.de
- Fix bug #12797: back to builtin behaviour, the widly used -I for
  bunzip2 can be reenabled with the environment var TAROLDOPT4BZIP2
* Mon Dec 17 2001 werner@suse.de
- draht@suse.de: package rsh is needed for build of tar(1) to
  enable rsh remote command execution.
  two successive execl() calls to /usr/bin/rsh with different
  args/remote commands do not make sense since the first execl() is
  successful if /usr/bin/rsh exists. Check for existence of /etc/rmt
  on the remote side and execute it, else exec /sbin/rmt . (#12605)
- Use one contstant string for command line
* Tue Nov 20 2001 werner@suse.de
- Add rsh to needeforbuild to be sure that remote shell for remote
  backup will be found.
* Wed Aug  1 2001 werner@suse.de
- Make /etc/rmt versus /sbin/rmt switch dynamic.
* Tue Mar 27 2001 werner@suse.de
- Fix man page of tar (#6741)
* Thu Dec 14 2000 werner@suse.de
- Update to tar 1.13.18
  * should avoid some crashes
  * avoid exclude file list problem
* Fri Nov 26 1999 kukuk@suse.de
- Add tar.1 to file list
- Remove obsolete entries from file list
- Build tar with locale support
